pub struct PotentialImpl { /* private fields */ }Expand description
Opaque potential handle wrapping a callback + user data.
Implementations
Sourceimpl PotentialImpl
impl PotentialImpl
Sourcepub fn new(
callback: PotentialCallback,
user_data: *mut c_void,
free_fn: Option<FreeFn>,
) -> Self
pub fn new( callback: PotentialCallback, user_data: *mut c_void, free_fn: Option<FreeFn>, ) -> Self
Create a new potential from a callback, user data, and optional destructor.
Sourcepub unsafe fn calculate(
&self,
input: *const rgpot_force_input_t,
output: *mut rgpot_force_out_t,
) -> rgpot_status_t
pub unsafe fn calculate( &self, input: *const rgpot_force_input_t, output: *mut rgpot_force_out_t, ) -> rgpot_status_t
Invoke the underlying callback.
Safety
The caller must ensure input and output point to valid, properly
sized structures.